diff --git a/examples/heart_rate_monitor/main.c b/examples/heart_rate_monitor/main.c
index 0a18a31..e814305 100644
--- a/examples/heart_rate_monitor/main.c
+++ b/examples/heart_rate_monitor/main.c
@@ -629,7 +629,56 @@ static void ble_evt_dispatch(adapter_t * adapter, ble_evt_t * p_ble_evt)
             m_send_notifications = false;
             advertising_start();
             break;
+#if NRF_SD_BLE_API == 6    
+        case BLE_GAP_EVT_PHY_UPDATE_REQUEST:
+        {
+            printf("PHY update request.");
+            ble_gap_phys_t const phys =
+            {
+                .rx_phys = BLE_GAP_PHY_AUTO,
+                .tx_phys = BLE_GAP_PHY_AUTO,
+            };
+            err_code = sd_ble_gap_phy_update(m_adapter, p_ble_evt->evt.gap_evt.conn_handle, &phys);
+            if (err_code != NRF_SUCCESS)
+            {
+                printf("sd_ble_gap_phy_update() failed. Error code: 0x%02X\n", err_code);
+                fflush(stdout);
+            }
+        } break;
+        case BLE_GAP_EVT_SEC_PARAMS_REQUEST:
+            // Pairing not supported
+            err_code = sd_ble_gap_sec_params_reply(m_adapter, m_connection_handle, BLE_GAP_SEC_STATUS_PAIRING_NOT_SUPP, NULL, NULL);
+            if (err_code != NRF_SUCCESS)
+            {
+                printf("sd_ble_gap_sec_params_reply() failed. Error code: 0x%02X\n", err_code);
+                fflush(stdout);
+            }
+            break;
 
+        case BLE_GAP_EVT_DATA_LENGTH_UPDATE_REQUEST:
+        {    
+            ble_gap_data_length_params_t const dlp =
+            {
+                .max_rx_octets  = 27,
+                .max_tx_octets  = 27,
+                .max_rx_time_us = BLE_GAP_DATA_LENGTH_AUTO,
+                .max_tx_time_us = BLE_GAP_DATA_LENGTH_AUTO,
+            };
+
+            ble_gap_data_length_limitation_t dll = {0};
+            
+            err_code = sd_ble_gap_data_length_update(m_adapter, m_connection_handle, &dlp, &dll);
+            if (err_code != NRF_SUCCESS)
+            {
+                printf("sd_ble_gap_sec_params_reply() failed. Error code: 0x%02X\n", err_code);
+                fflush(stdout);
+            }
+        } break;
+
+        case BLE_GAP_EVT_DATA_LENGTH_UPDATE:
+            printf("Data length updated. %d", p_ble_evt->evt.gap_evt.params.data_length_update.effective_params.max_tx_octets);
+            break;
+#endif 
         case BLE_GAP_EVT_TIMEOUT:
             printf("Advertisement timed out\n");
             fflush(stdout);
